<template>
    <div class="notice">
        <el-dialog
            v-model="dialogVisible"
            :title="title"
            width="900px"
            :before-close="handleClose"
        >
            <el-form :model="state.form" inline size="default" ref="busRef" :rules="state.formRules" label-width="140px" >
              <el-form-item label="姓名:" prop="name">
                  <el-input v-model.trim="state.form.name" readonly></el-input>
              </el-form-item>
              <el-form-item label="身份证号:" prop="idCard">
                <el-input v-model.trim="state.form.idCard" readonly></el-input>
              </el-form-item>
              <el-form-item label="项目名称:" prop="projectName">
                <el-input v-model.trim="state.form.projectName" readonly></el-input>
              </el-form-item>
              <el-form-item label="是否为专家组组长:" prop="leader">
                <el-input v-model.trim="state.form.leader" readonly></el-input>
              </el-form-item>
              <el-form-item label="考评记录时间:" prop="updateTime">
                <el-input v-model.trim="state.form.updateTime" readonly></el-input>
              </el-form-item>
              <el-form-item label="总计:" prop="score">
                <el-input v-model.trim="state.form.score" readonly></el-input>
              </el-form-item>
            </el-form>
          <el-table :data="state.form.tableData" border style="width: 100%">
            <el-table-column prop="content" label="加（扣）分项目"/>
            <el-table-column prop="score" label="分值明细" />
          </el-table>
            <template #footer>
                    <span class="dialog-footer">
                        <el-button type="primary"  @click="handleClose" size="default" v-preReClick>确认</el-button>
                    </span>
            </template>
        </el-dialog>
    </div>
</template>
<script setup>
import {reactive, ref, toRefs} from 'vue'
import Editor from "@/components/Editor/index.vue";
import {ElMessage} from "element-plus";
import {addNotice} from "@/api/backManage/notice";
import {addDict, editDict, getDictDetail, getExpertEvaDetail} from "@/api/backManage/evaluate";

const dialogVisible = ref(false);
const title = ref("");
const busRef = ref();
const emit = defineEmits(["getList"]);
const state = reactive({
    form: {
      name: '',
      idCard: '',
      projectName: '',
      leader: '',
      updateTime: '',
      score: '',
      tableData: []
    },
    formRules:{
        label: [{ required: true, message: '请输入类型', trigger: 'blur' }],
    },

})

const openDialog = async (type, value) => {
    title.value = type === 'add' ? '新增' : type ==='edit' ? '编辑' : '查看' ;
    if(type === 'edit' || type === 'view') {
        state.form = value
      state.form.leader = value.teamLeader==1?'是':'否'
        const param = {
          projectExpertId: value.projectExpertId
        }
        const res = await getExpertEvaDetail(param);
        if(res.code === 200){
            state.form.tableData = res.data.expertDetails
        }else{
            ElMessage.warning(res.msg)
        }
    }
    dialogVisible.value = true;
}

const handleClose = () => {
    busRef.value.clearValidate();
    reset();
    dialogVisible.value = false;

}
const reset = () => {
    state.form = {
        id: '',
        label: '',
        value: '',
        dictType: "sys_assess_type",
    }
}
defineExpose({
    openDialog
});

</script>

<style scoped lang="scss">
.notice{
    :deep(.el-form .el-form-item__label) {
        font-size: 15px;
    }
    .file {
        display: flex;
        flex-direction: column;
        align-items: flex-start;
    }
}
</style>
